pub struct CsiVolume {Show 35 fields
pub id: String,
pub name: String,
pub external_id: Option<String>,
pub namespace: String,
pub requested_topologies: Option<CsiTopologyRequest>,
pub topologies: Vec<CsiTopology>,
pub access_mode: CsiVolumeAccessMode,
pub attachment_mode: CsiVolumeAttachmentMode,
pub mount_options: Option<CsiMountOptions>,
pub secrets: Option<HashMap<String, String>>,
pub parameters: Option<HashMap<String, String>>,
pub context: Option<HashMap<String, String>>,
pub capacity: i64,
pub requested_capacity_min: i64,
pub requested_capacity_max: i64,
pub requested_capabilities: Vec<CsiVolumeCapability>,
pub clone_id: Option<String>,
pub snapshot_id: Option<String>,
pub read_allocs: HashMap<String, Allocation>,
pub write_allocs: HashMap<String, Allocation>,
pub allocations: Vec<AllocationListStub>,
pub schedulable: bool,
pub plugin_id: Option<String>,
pub provider: String,
pub provider_version: String,
pub controller_required: bool,
pub controllers_healthy: i64,
pub controllers_expected: i64,
pub nodes_healthy: i64,
pub nodes_expected: i64,
pub resource_exhausted: DateTime<Utc>,
pub create_index: u64,
pub modify_index: u64,
pub create_time: i64,
pub modify_time: i64,
}Expand description
CSIVolume is used for serialization, see also nomad/structs/csi.go
This struct was generated based on the Go types of the official Nomad API client.
Fields
id: Stringname: Stringexternal_id: Option<String>namespace: Stringrequested_topologies: Option<CsiTopologyRequest>RequestedTopologies are the topologies submitted as options to the storage provider at the time the volume was created. After volumes are created, this field is ignored.
topologies: Vec<CsiTopology>Topologies are the topologies returned by the storage provider, based on the RequestedTopologies and what the storage provider could support. This value cannot be set by the user.
access_mode: CsiVolumeAccessModeattachment_mode: CsiVolumeAttachmentModemount_options: Option<CsiMountOptions>secrets: Option<HashMap<String, String>>parameters: Option<HashMap<String, String>>context: Option<HashMap<String, String>>capacity: i64requested_capacity_min: i64These fields are used as part of the volume creation request
requested_capacity_max: i64requested_capabilities: Vec<CsiVolumeCapability>clone_id: Option<String>snapshot_id: Option<String>read_allocs: HashMap<String, Allocation>ReadAllocs is a map of allocation IDs for tracking reader claim status. The Allocation value will always be nil; clients can populate this data by iterating over the Allocations field.
write_allocs: HashMap<String, Allocation>WriteAllocs is a map of allocation IDs for tracking writer claim status. The Allocation value will always be nil; clients can populate this data by iterating over the Allocations field.
allocations: Vec<AllocationListStub>Allocations is a combined list of readers and writers
schedulable: boolSchedulable is true if all the denormalized plugin health fields are true
plugin_id: Option<String>provider: Stringprovider_version: Stringcontroller_required: boolcontrollers_healthy: i64controllers_expected: i64nodes_healthy: i64nodes_expected: i64resource_exhausted: DateTime<Utc>create_index: u64modify_index: u64create_time: i64CreateTime stored as UnixNano
modify_time: i64ModifyTime stored as UnixNano