DeregisterOptionsBuilder

Struct DeregisterOptionsBuilder 

pub struct DeregisterOptionsBuilder { /* private fields */ }
Builder for DeregisterOptions.

Implementations

Source

impl DeregisterOptionsBuilder

pub fn purge(&mut self, value: bool) -> &mut Self

If Purge is set to true, the job is deregistered and purged from the system versus still being queryable and eventually GC’ed from the system. Most callers should not specify purge.

pub fn global(&mut self, value: bool) -> &mut Self

If Global is set to true, all regions of a multiregion job will be stopped.

pub fn eval_priority(&mut self, value: i64) -> &mut Self

EvalPriority is an optional priority to use on any evaluation created as a result on this job deregistration. This value must be between 1-100 inclusively, where a larger value corresponds to a higher priority. This is useful when an operator wishes to push through a job deregistration in busy clusters with a large evaluation backlog.

pub fn no_shutdown_delay(&mut self, value: bool) -> &mut Self

NoShutdownDelay, if set to true, will override the group and task shutdown_delay configuration and ignore the delay for any allocations stopped as a result of this Deregister call.

pub fn build(&self) -> Result<DeregisterOptions, DeregisterOptionsBuilderError>

Builds a new DeregisterOptions.

Errors

If a required field has not been initialized.