pub struct RegisterOptions {
pub enforce_index: bool,
pub modify_index: u64,
pub policy_override: bool,
pub preserve_counts: bool,
pub eval_priority: i64,
pub submission: Option<JobSubmission>,
}Expand description
RegisterOptions is used to pass through job registration parameters
This struct was generated based on the Go types of the official Nomad API client.
Fields
enforce_index: boolmodify_index: u64policy_override: boolpreserve_counts: booleval_priority: i64submission: Option<JobSubmission>Implementations
Sourceimpl RegisterOptions
impl RegisterOptions
pub fn builder() -> RegisterOptionsBuilder